.. django-contactform documentation master file, created by
   sphinx-quickstart on Tue May  5 23:30:51 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-contactform's documentation!
==============================================

Prerequisites
-------------

- Django >= 3.0
- Python >= 3.5

Topics
------

.. toctree::
   :maxdepth: 2

   Install <install>
   Settings <settings>
   Templates <templates>
   Template Tags <templatetags>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
